package com.ruoyi.system.service;

import com.ruoyi.system.domain.visitor.VisitorRecords;

import java.util.List;


/**
 * 访客车辆登记Service接口
 * 
 * @author boman
 * @date 2025-02-14
 */
public interface IVisitorRecordsService 
{
    /**
     * 查询访客车辆登记
     * 
     * @param visitorRecordsId 访客车辆登记主键
     * @return 访客车辆登记
     */
    public VisitorRecords selectVisitorRecordsByVisitorRecordsId(Long visitorRecordsId);

    /**
     * 查询访客车辆登记列表
     * 
     * @param visitorRecords 访客车辆登记
     * @return 访客车辆登记集合
     */
    public List<VisitorRecords> selectVisitorRecordsList(VisitorRecords visitorRecords);

    /**
     * 新增访客车辆登记
     * 
     * @param visitorRecords 访客车辆登记
     * @return 结果
     */
    public int insertVisitorRecords(VisitorRecords visitorRecords);

    /**
     * 修改访客车辆登记
     * 
     * @param visitorRecords 访客车辆登记
     * @return 结果
     */
    public int updateVisitorRecords(VisitorRecords visitorRecords);

    /**
     * 批量删除访客车辆登记
     * 
     * @param visitorRecordsIds 需要删除的访客车辆登记主键集合
     * @return 结果
     */
    public int deleteVisitorRecordsByVisitorRecordsIds(Long[] visitorRecordsIds);

    /**
     * 删除访客车辆登记信息
     * 
     * @param visitorRecordsId 访客车辆登记主键
     * @return 结果
     */
    public int deleteVisitorRecordsByVisitorRecordsId(Long visitorRecordsId);
}
